@@ -112,11 +112,11 @@ VALUE:
 
 QUOTED_STRING:
 		/"([^\\"]*(?:\\.[^\\"]*)*)"/
-		{ 	$item[1] =~ s/\\(.)/$1/;
-			$return = $item[1]; 1 }
+		{ 	$return = $1;
+			$return =~ s/\\(.)/$1/; 1 }
 	|	/'([^\\']*(?:\\.[^\\']*)*)'/
-		{ 	$item[1] =~ s/\\(.)/$1/;
-			$return = $item[1]; 1 }
+		{ 	$return = $1;
+			$return =~ s/\\(.)/$1/; 1 }
 
 EOF:
 		/\Z/
